@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Apply melodic inversion to a series of notes
 
-our $VERSION = '0.0101';
+our $VERSION = '0.0102';
 
 use Data::Dumper::Compact qw(ddc);
 use List::SomeUtils qw(first_index);
@@ -38,10 +38,10 @@ sub _build__scale {
     my @scale = get_scale_notes($self->scale_note, $self->scale_name);
     print 'Scale: ', ddc(\@scale) if $self->verbose;
 
-    my @scale_octaves = map { my $o = $_; map { $_ . $o } @scale } -1 .. 9;
-    print 'Scale octaves: ', ddc(\@scale_octaves) if $self->verbose;
+    my @with_octaves = map { my $o = $_; map { $_ . $o } @scale } -1 .. 9;
+    print 'With octaves: ', ddc(\@with_octaves) if $self->verbose;
 
-    return \@scale_octaves;
+    return \@with_octaves;
 }
 
 
@@ -89,11 +89,9 @@ sub invert {
 
     my $intervals = $self->intervals($notes);
 
-    my @scale_octaves = @{ $self->_scale };
-
     for my $interval (@$intervals) {
         # Find the note that is the opposite interval away from the original note
-        my $pitch = $scale_octaves[ (first_index { $_ eq $note } @scale_octaves) - $interval ];
+        my $pitch = $self->_scale->[ (first_index { $_ eq $note } @{ $self->_scale }) - $interval ];
 
         push @inverted, $pitch;
 
@@ -119,7 +117,7 @@ Music::MelodicDevice::Inversion - Apply melodic inversion to a series of notes
 
 =head1 VERSION
 
-version 0.0101
+version 0.0102
 
 =head1 SYNOPSIS
 
@@ -127,13 +125,15 @@ version 0.0101
 
   my @notes = qw(C4 E4 D4 G4 C5);
 
-  my $md = Music::MelodicDevice::Inversion->new(scale_name => 'major');
-  my $intervals = $md->intervals(\@notes); # [2, -1, 3, 3]
-  my $inv = $md->invert('C4', \@notes); # [C4, A3, B3, F3, C3]
+  # Chromatic
+  my $md = Music::MelodicDevice::Inversion->new;
+  my $intervals = $md->intervals(\@notes); # [4, -2, 5, 5]
+  my $inv = $md->invert('C4', \@notes); # [C4, G#3, A#3, F3, C3]
 
-  $md = Music::MelodicDevice::Inversion->new(scale_name => 'chromatic');
-  $intervals = $md->intervals(\@notes); # [4, -2, 5, 5]
-  $inv = $md->invert('C4', \@notes); # [C4, G#3, A#3, F3, C3]
+  # Diatonic
+  $md = Music::MelodicDevice::Inversion->new(scale_name => 'major');
+  $intervals = $md->intervals(\@notes); # [2, -1, 3, 3]
+  $inv = $md->invert('C4', \@notes); # [C4, A3, B3, F3, C3]
 
 =head1 DESCRIPTION
 
@@ -175,12 +175,18 @@ Create a new C<Music::MelodicDevice::Inversion> object.
 
   $intervals = $md->intervals($notes);
 
+Return the positive or negative intervals between successive B<notes>.
+
 =head2 invert
 
   $inverted = $md->invert($note, $notes);
 
+Return the inverted series of notes.
+
 =head1 SEE ALSO
 
+The F<t/01-methods.t> and F<eg/> distribution programs
+
 L<Music::AtonalUtil> (contains a similar "invert" method)
 
 L<MIDI::Praxis::Variation> (contains a mystery "inversion" function)
